@@ -58,7 +58,6 @@ class SSSDOptions(object):
         'enum_cache_timeout': _('Enumeration cache timeout length (seconds)'),
         'entry_cache_no_wait_timeout': _('Entry cache background update timeout length (seconds)'),
         'entry_negative_timeout': _('Negative cache timeout length (seconds)'),
-        'local_negative_timeout': _('Files negative cache timeout length (seconds)'),
         'filter_users': _('Users that SSSD should explicitly ignore'),
         'filter_groups': _('Groups that SSSD should explicitly ignore'),
         'filter_users_in_groups': _('Should filtered users appear in groups'),
@@ -197,6 +196,8 @@ class SSSDOptions(object):
         'refresh_expired_interval': _('How often should expired entries be refreshed in background'),
         'refresh_expired_interval_offset': _("Maximum period deviation when refreshing expired entries in background"),
         'dyndns_update': _("Whether to automatically update the client's DNS entry"),
+        'dyndns_update_per_family': _('Whether DNS update of A and AAAA record should be performed '
+                                      'in one update or in two separate updates'),
         'dyndns_ttl': _("The TTL to apply to the client's DNS entry after updating it"),
         'dyndns_iface': _("The interface whose IP should be used for dynamic DNS updates"),
         'dyndns_refresh_interval': _("How often to periodically update the client's DNS entry"),
@@ -205,6 +206,9 @@ class SSSDOptions(object):
         'dyndns_force_tcp': _("Whether the nsupdate utility should default to using TCP"),
         'dyndns_auth': _("What kind of authentication should be used to perform the DNS update"),
         'dyndns_server': _("Override the DNS server used to perform the DNS update"),
+        'dyndns_dot_cacert': _("The file of the certificate authorities certificates for DoT"),
+        'dyndns_dot_cert': _("The certificate(s) file for authentication for the DoT transport"),
+        'dyndns_dot_key': _("The key file for authenticated encryption for the DoT transport"),
         'subdomain_enumerate': _('Control enumeration of trusted domains'),
         'subdomain_refresh_interval': _('How often should subdomains list be refreshed'),
         'subdomain_refresh_interval_offset': _('Maximum period deviation when refreshing the subdomain list'),
@@ -354,6 +358,7 @@ class SSSDOptions(object):
         'ldap_uri': _('ldap_uri, The URI of the LDAP server'),
         'ldap_backup_uri': _('ldap_backup_uri, The URI of the LDAP server'),
         'ldap_search_base': _('The default base DN'),
+        'ldap_read_rootdse': _('How to read rootDSE from LDAP server'),
         'ldap_schema': _('The Schema Type in use on the LDAP server, rfc2307'),
         'ldap_pwmodify_mode': _('Mode used to change user password'),
         'ldap_default_bind_dn': _('The default bind DN'),
